"""
Temperature Conversion Package
===============================
This package provides functions to convert temperatures between Celsius, Fahrenheit, Kelvin, and Rankine scales.

Functions:
----------
- celsius_to_fahrenheit(c)
- celsius_to_kelvin(c)
- celsius_to_rankine(c)
- fahrenheit_to_celsius(f)
- fahrenheit_to_kelvin(f)
- fahrenheit_to_rankine(f)
- kelvin_to_celsius(k)
- kelvin_to_fahrenheit(k)
- kelvin_to_rankine(k)
- rankine_to_celsius(r)
- rankine_to_fahrenheit(r)
- rankine_to_kelvin(r)
"""

from .functions import *

# Package metadata
__version__ = "1.2.0"
__author__ = "Zeeshan Khalid"
__email__ = "nszeeshankhalid@gmail.com"

__all__ = [
    "celsius_to_fahrenheit",
    "celsius_to_kelvin",
    "celsius_to_rankine",
    "fahrenheit_to_celsius",
    "fahrenheit_to_kelvin",
    "fahrenheit_to_rankine",
    "kelvin_to_celsius",
    "kelvin_to_fahrenheit",
    "kelvin_to_rankine",
    "rankine_to_celsius",
    "rankine_to_fahrenheit",
    "rankine_to_kelvin",
]



import pytest
import warnings
from pytemperatureconverter import (
    celsius_to_fahrenheit,
    celsius_to_kelvin,
    celsius_to_rankine,
    fahrenheit_to_celsius,
    fahrenheit_to_kelvin,
    fahrenheit_to_rankine,
    kelvin_to_celsius,
    kelvin_to_fahrenheit,
    kelvin_to_rankine,
    rankine_to_celsius,
    rankine_to_fahrenheit,
    rankine_to_kelvin,
)

# Suppress warnings during testing
@pytest.fixture(autouse=True)
def suppress_warnings():
    warnings.simplefilter("ignore", UserWarning)

def test_celsius_conversions():
    assert celsius_to_fahrenheit(0) == 32.0
    assert celsius_to_kelvin(0) == 273.15
    assert celsius_to_rankine(0) == 491.67
    assert celsius_to_fahrenheit(-273.15) == -459.67
    assert celsius_to_kelvin(-273.15) == 0.0
    assert celsius_to_rankine(-273.15) == 0.0

def test_fahrenheit_conversions():
    assert fahrenheit_to_celsius(32) == 0.0
    assert fahrenheit_to_kelvin(32) == 273.15
    assert fahrenheit_to_rankine(32) == 491.67
    assert fahrenheit_to_celsius(-459.67) == -273.15
    assert fahrenheit_to_kelvin(-459.67) == 0.0
    assert fahrenheit_to_rankine(-459.67) == 0.0

def test_kelvin_conversions():
    assert kelvin_to_celsius(273.15) == 0.0
    assert kelvin_to_fahrenheit(273.15) == 32.0
    assert kelvin_to_rankine(273.15) == 491.67
    assert kelvin_to_celsius(0) == -273.15
    assert kelvin_to_fahrenheit(0) == -459.67
    assert kelvin_to_rankine(0) == 0.0

def test_rankine_conversions():
    assert rankine_to_celsius(491.67) == 0.0
    assert rankine_to_fahrenheit(491.67) == 32.0
    assert rankine_to_kelvin(491.67) == 273.15
    assert rankine_to_celsius(0) == -273.15
    assert rankine_to_fahrenheit(0) == -459.67
    assert rankine_to_kelvin(0) == 0.0


import warnings

"""A simple python script to convert temperature between four scales"""

# Define a function to convert Celsius to Fahrenheit
def celsius_to_fahrenheit(c):
    if c < -273.15:
        warnings.warn("Celsius value is below absolute zero!", UserWarning)
    return round(1.8 * c + 32, 2)

# Define a function to convert Celsius to Kelvin
def celsius_to_kelvin(c):
    if c < -273.15:
        warnings.warn("Celsius value is below absolute zero!", UserWarning)
    return round(c + 273.15, 2)

# Define a function to convert Celsius to Rankine
def celsius_to_rankine(c):
    if c < -273.15:
        warnings.warn("Celsius value is below absolute zero!", UserWarning)
    return round(1.8 * c + 491.67, 2)

# Define a function to convert Fahrenheit to Celsius
def fahrenheit_to_celsius(f):
    if f < -459.67:
        warnings.warn("Fahrenheit value is below absolute zero!", UserWarning)
    return round((f - 32) / 1.8, 2)

# Define a function to convert Fahrenheit to Kelvin
def fahrenheit_to_kelvin(f):
    if f < -459.67:
        warnings.warn("Fahrenheit value is below absolute zero!", UserWarning)
    return round((f + 459.67) / 1.8, 2)

# Define a function to convert Fahrenheit to Rankine
def fahrenheit_to_rankine(f):
    if f < -459.67:
        warnings.warn("Fahrenheit value is below absolute zero!", UserWarning)
    return round(f + 459.67, 2)

# Define a function to convert Kelvin to Celsius
def kelvin_to_celsius(k):
    if k < 0:
        warnings.warn("Kelvin value is below absolute zero!", UserWarning)
    return round(k - 273.15, 2)

# Define a function to convert Kelvin to Fahrenheit
def kelvin_to_fahrenheit(k):
    if k < 0:
        warnings.warn("Kelvin value is below absolute zero!", UserWarning)
    return round(1.8 * k - 459.67, 2)

# Define a function to convert Kelvin to Rankine
def kelvin_to_rankine(k):
    if k < 0:
        warnings.warn("Kelvin value is below absolute zero!", UserWarning)
    return round(1.8 * k, 2)

# Define a function to convert Rankine to Celsius
def rankine_to_celsius(r):
    if r < 0:
        warnings.warn("Rankine value is below absolute zero!", UserWarning)
    return round((r - 491.67) / 1.8, 2)

# Define a function to convert Rankine to Fahrenheit
def rankine_to_fahrenheit(r):
    if r < 0:
        warnings.warn("Rankine value is below absolute zero!", UserWarning)
    return round(r - 459.67, 2)

# Define a function to convert Rankine to Kelvin
def rankine_to_kelvin(r):
    if r < 0:
        warnings.warn("Rankine value is below absolute zero!", UserWarning)
    return round(r / 1.8, 2)

# Define an __all__ variable that lists the names of the functions you want to expose
__all__ = [
    "celsius_to_fahrenheit",
    "celsius_to_kelvin",
    "celsius_to_rankine",
    "fahrenheit_to_celsius",
    "fahrenheit_to_kelvin",
    "fahrenheit_to_rankine",
    "kelvin_to_celsius",
    "kelvin_to_fahrenheit",
    "kelvin_to_rankine",
    "rankine_to_celsius",
    "rankine_to_fahrenheit",
    "rankine_to_kelvin",
]



from setuptools import setup, find_packages

setup(
    name="pytemperatureconverter",
    version="1.2.0",
    author="Zeeshan Khalid",
    author_email="nszeeshankhalid@gmail.com",
    description="A simple Python library to convert temperatures between four scales (Celsius, Fahrenheit, Kelvin, and Rankine) with warnings for physically impossible conversions.",
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/manxlr",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
